@@ -1,5 +1,5 @@
 #
-# $Id: String.pm,v 0.01 2004/01/01 18:11:37 st.schubiger Exp $
+# $Id: String.pm,v 0.02 2004/01/02 00:30:33 st.schubiger Exp $
 
 package Convert::ASCII::String;
 
@@ -17,7 +17,7 @@ our (@EXPORT_OK, %EXPORT_TAGS, @subs, $VERSION);
 @EXPORT_OK = @subs;
 %EXPORT_TAGS = ( 'all' => [ @subs ] );
 
-$VERSION = 0.01;
+$VERSION = '0.02';
 
 =head1 NAME
 
@@ -25,7 +25,7 @@ Convert::ASCII::String - Convert character strings to ASCII and vice versa.
 
 =head1 SYNOPSIS
 
-    use Convert::ASCII::String;
+    use Convert::ASCII::String q/:all/;
 
     my $wisdom = 'Premature optimization is the root of all evil.';
 
@@ -82,12 +82,12 @@ Convert a character string to ASCII inserting a separator between each ASCII cod
 =cut
 
 sub string2ascii {
-    my ($data_ref, $item_sep) = @_;
-    croak q~Syntax: string2ascii (\$data, $separator)~
-      unless ref $data_ref eq 'SCALAR' && $item_sep;
+    my ($data_ref, $sep) = @_;
+    croak q~usage: string2ascii (\$data, $separator)~
+      unless ref $data_ref eq 'SCALAR' && $sep;
 
     my @ascii = unpack 'C*', $$data_ref;
-    $$data_ref = join $item_sep, @ascii;
+    $$data_ref = join $sep, @ascii;
 }
 
 =head2 ascii2string ( \$data, $separator )
@@ -99,24 +99,25 @@ And vice versa.
 =cut
 
 sub ascii2string {
-    my ($data_ref, $item_sep) = @_;
-    croak q~Syntax: ascii2string (\$data, $separator)~
-      unless ref $data_ref eq 'SCALAR' && $item_sep;
+    my ($data_ref, $sep) = @_;
+    croak q~usage: ascii2string (\$data, $separator)~
+      unless ref $data_ref eq 'SCALAR' && $sep;
 
-    $item_sep = quotemeta $item_sep;
-    my @ascii = split /$item_sep/, $$data_ref;
+    $sep = quotemeta $sep;
+    my @ascii = split $sep, $$data_ref;
     $$data_ref = pack 'C*', @ascii;
 }
 
 1;
-
 __END__
 
 =head2 EXPORT
 
 C<string2ascii()> and C<ascii2string()> upon request.
 
-C<:all> exports both.
+=head3 TAGS
+
+:all - C<*()>
 
 =head1 SEE ALSO
 
